/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


import jgromacs.data.FrameIndexSet;
import junit.framework.TestCase;

import org.junit.Test;


public class FrameIndexSetTest extends TestCase{

	@Test
	public void testGetNumberOfFrames() {

		FrameIndexSet fset = new FrameIndexSet();
		fset.addFrame(1);
		fset.addFrame(3);
		fset.addFrame(5);
		fset.addFrame(7);
		fset.addFrame(9);
		fset.addFrame(11);
		fset.addFrame(13);
		fset.addFrame(15);
		fset.addFrame(17);
		
		assertEquals(9, fset.getNumberOfFrames());
	}

	@Test
	public void testIsIndexIn() {
		
		FrameIndexSet fset = new FrameIndexSet();
		fset.addFrame(1);
		fset.addFrame(3);
		fset.addFrame(5);
		fset.addFrame(7);
		fset.addFrame(9);
		fset.addFrame(11);
		fset.addFrame(13);
		fset.addFrame(15);
		fset.addFrame(17);
		
		assertTrue(!fset.isFrameIn(2));
		assertTrue(!fset.isFrameIn(10));
		assertTrue(fset.isFrameIn(11));
		assertTrue(fset.isFrameIn(17));
		assertTrue(!fset.isFrameIn(19));
	}

	@Test
	public void testaddFrame() {
		
		FrameIndexSet fset = new FrameIndexSet();
	
		assertTrue(!fset.isFrameIn(919));
		
		fset.addFrame(919);
		
		assertTrue(fset.isFrameIn(919));
	}

	@Test
	public void testRemoveIndex() {
		
		FrameIndexSet fset = new FrameIndexSet();
		fset.addFrame(1);
		fset.addFrame(3);
		fset.addFrame(5);
		fset.addFrame(7);
		
		assertTrue(fset.isFrameIn(5));
		
		fset.removeFrame(5);
		
		assertTrue(!fset.isFrameIn(5));
	}

	@Test
	public void testIntersect() {
		FrameIndexSet fset = new FrameIndexSet();
		fset.addFrame(1);
		fset.addFrame(3);
		fset.addFrame(5);
		fset.addFrame(7);
		fset.addFrame(9);
		
		FrameIndexSet fset2 = new FrameIndexSet();
		fset2.addFrame(2);
		fset2.addFrame(3);
		fset2.addFrame(4);
		fset2.addFrame(7);
		fset2.addFrame(11);
		
		FrameIndexSet calc = fset.intersect(fset2);
		calc.setName("");
		
		FrameIndexSet control = new FrameIndexSet("");
		control.addFrame(3);
		control.addFrame(7);
				
		assertEquals(control, calc);
	}

	@Test
	public void testSubtract() {
		FrameIndexSet fset = new FrameIndexSet();
		fset.addFrame(1);
		fset.addFrame(3);
		fset.addFrame(5);
		fset.addFrame(7);
		fset.addFrame(9);
		
		FrameIndexSet fset2 = new FrameIndexSet();
		fset2.addFrame(2);
		fset2.addFrame(3);
		fset2.addFrame(4);
		fset2.addFrame(7);
		fset2.addFrame(11);
		
		FrameIndexSet calc = fset.subtract(fset2);
		calc.setName("");
		
		FrameIndexSet control = new FrameIndexSet("");
		control.addFrame(1);
		control.addFrame(5);
		control.addFrame(9);
				
		assertEquals(control, calc);
	}

	@Test
	public void testUnion() {
		FrameIndexSet fset = new FrameIndexSet();
		fset.addFrame(1);
		fset.addFrame(3);
		fset.addFrame(5);
		fset.addFrame(7);
		fset.addFrame(9);
		
		FrameIndexSet fset2 = new FrameIndexSet();
		fset2.addFrame(2);
		fset2.addFrame(3);
		fset2.addFrame(4);
		fset2.addFrame(7);
		fset2.addFrame(11);
	
		FrameIndexSet calc = fset.union(fset2);
		calc.setName("");
		
		FrameIndexSet control = new FrameIndexSet("");
		control.addFrame(1);
		control.addFrame(2);
		control.addFrame(3);
		control.addFrame(4);
		control.addFrame(5);
		control.addFrame(7);
		control.addFrame(9);
		control.addFrame(11);
				
		assertEquals(control, calc);
	}
	
	@Test
	public void testCloneEquals() {
		
		FrameIndexSet x = new FrameIndexSet();
		x.addFrame(1);
		x.addFrame(3);
		x.addFrame(5);
		
		FrameIndexSet cx = (FrameIndexSet)x.clone();
		
		assertTrue(x.equals(cx));
		assertTrue(x!=cx);
		
		x.addFrame(7);
		assertTrue(!x.equals(cx));
		
	}
	
}
