/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


import java.io.IOException;

import jgromacs.data.IndexSet;
import jgromacs.data.IndexSetList;
import jgromacs.io.IOData;
import junit.framework.TestCase;

import org.junit.Test;

public class IndexSetListTest extends TestCase{

	@Test
	public void testGetNumberOfAtomsInIndexSetInt() {
		
		try {
			
			IndexSetList isetlist = IOData.readIndexSetListFromNDX("dataset//example.ndx");
						
			assertEquals(5, isetlist.getNumberOfAtomsInIndexSet(0)); // Number of indices in first index group
			assertEquals(10, isetlist.getNumberOfAtomsInIndexSet(1)); // Number of indices in second index group
			
			} catch (IOException e) {
				fail(e.toString());
			}
	}

	@Test
	public void testGetNumberOfAtomsInIndexSetString() {
		
		try {
			
			IndexSetList isetlist = IOData.readIndexSetListFromNDX("dataset//example.ndx");
						
			assertEquals(5, isetlist.getNumberOfAtomsInIndexSet("set1")); // Number of indices in index group "set1"
			assertEquals(10, isetlist.getNumberOfAtomsInIndexSet("set2")); // Number of indices in index group "set2"
			
			} catch (IOException e) {
				fail(e.toString());
			}
	}

	@Test
	public void testFuseIntoOneIndexSet() {
		
		try {
			
			IndexSetList isetlist = IOData.readIndexSetListFromNDX("dataset//example.ndx");
						
			IndexSet iset = isetlist.fuseIntoOneIndexSet(); //  The two index groups are merged into one
			iset.setName("");
			
			IndexSet control = new IndexSet("");
			for (int i = 17; i < 22; i++) control.addIndex(i);
			for (int i = 71; i < 81; i++) control.addIndex(i);
			
			assertEquals(control, iset);
			
			} catch (IOException e) {
				fail(e.toString());
			}
	}
	
	@Test
	public void testCloneEquals() {

		try {
			
			IndexSetList x = IOData.readIndexSetListFromNDX("dataset//example.ndx");
			
			IndexSetList cx = (IndexSetList)x.clone();
			
			assertTrue(x.equals(cx));
			assertTrue(x!=cx);
			
			x.removeIndexSet(0);
			assertTrue(!x.equals(cx));
			
			} catch (IOException e) {
				fail(e.toString());
			}
			
	
	}

}
