/**
 * 
 * Written by Mrton Mnz and Philip C Biggin
 * Copyright (c) University of Oxford, United Kingdom
 * Visit http://sbcb.bioch.ox.ac.uk/jgromacs/
 * 
 * This source code file is part of JGromacs v1.0.
 * 
 * JGromacs v1.0 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * JGromacs v1.0. is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with JGromacs v1.0. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


import jgromacs.data.IndexSet;
import junit.framework.TestCase;

import org.junit.Test;

public class IndexSetTest extends TestCase {

	@Test
	public void testGetNumberOfIndices() {

		IndexSet iset = new IndexSet();
		iset.addIndex(1);
		iset.addIndex(3);
		iset.addIndex(5);
		iset.addIndex(7);
		iset.addIndex(9);
		iset.addIndex(11);
		iset.addIndex(13);
		iset.addIndex(15);
		iset.addIndex(17);
		
		assertEquals(9, iset.getNumberOfIndices());
	}

	@Test
	public void testIsIndexIn() {
		
		IndexSet iset = new IndexSet();
		iset.addIndex(1);
		iset.addIndex(3);
		iset.addIndex(5);
		iset.addIndex(7);
		iset.addIndex(9);
		iset.addIndex(11);
		iset.addIndex(13);
		iset.addIndex(15);
		iset.addIndex(17);
		
		assertTrue(!iset.isIndexIn(2));
		assertTrue(!iset.isIndexIn(10));
		assertTrue(iset.isIndexIn(11));
		assertTrue(iset.isIndexIn(17));
		assertTrue(!iset.isIndexIn(19));
	}

	@Test
	public void testAddIndex() {
		
		IndexSet iset = new IndexSet();
	
		assertTrue(!iset.isIndexIn(919));
		
		iset.addIndex(919);
		
		assertTrue(iset.isIndexIn(919));
	}

	@Test
	public void testRemoveIndex() {
		
		IndexSet iset = new IndexSet();
		iset.addIndex(1);
		iset.addIndex(3);
		iset.addIndex(5);
		iset.addIndex(7);
		
		assertTrue(iset.isIndexIn(5));
		
		iset.removeIndex(5);
		
		assertTrue(!iset.isIndexIn(5));
	}

	@Test
	public void testIntersect() {
		IndexSet iset = new IndexSet();
		iset.addIndex(1);
		iset.addIndex(3);
		iset.addIndex(5);
		iset.addIndex(7);
		iset.addIndex(9);
		
		IndexSet iset2 = new IndexSet();
		iset2.addIndex(2);
		iset2.addIndex(3);
		iset2.addIndex(4);
		iset2.addIndex(7);
		iset2.addIndex(11);
		
		IndexSet calc = iset.intersect(iset2);
		calc.setName("");
		
		IndexSet control = new IndexSet("");
		control.addIndex(3);
		control.addIndex(7);
				
		assertEquals(control, calc);
	}

	@Test
	public void testSubtract() {
		IndexSet iset = new IndexSet();
		iset.addIndex(1);
		iset.addIndex(3);
		iset.addIndex(5);
		iset.addIndex(7);
		iset.addIndex(9);
		
		IndexSet iset2 = new IndexSet();
		iset2.addIndex(2);
		iset2.addIndex(3);
		iset2.addIndex(4);
		iset2.addIndex(7);
		iset2.addIndex(11);
		
		IndexSet calc = iset.subtract(iset2);
		calc.setName("");
		
		IndexSet control = new IndexSet("");
		control.addIndex(1);
		control.addIndex(5);
		control.addIndex(9);
				
		assertEquals(control, calc);
	}

	@Test
	public void testUnion() {
		IndexSet iset = new IndexSet();
		iset.addIndex(1);
		iset.addIndex(3);
		iset.addIndex(5);
		iset.addIndex(7);
		iset.addIndex(9);
		
		IndexSet iset2 = new IndexSet();
		iset2.addIndex(2);
		iset2.addIndex(3);
		iset2.addIndex(4);
		iset2.addIndex(7);
		iset2.addIndex(11);
		
		IndexSet calc = iset.union(iset2);
		calc.setName("");
		
		IndexSet control = new IndexSet("");
		control.addIndex(1);
		control.addIndex(2);
		control.addIndex(3);
		control.addIndex(4);
		control.addIndex(5);
		control.addIndex(7);
		control.addIndex(9);
		control.addIndex(11);
				
		assertEquals(control, calc);
	}
	
	@Test
	public void testCloneEquals() {
		
		IndexSet x = new IndexSet();
		x.addIndex(1);
		x.addIndex(3);
		x.addIndex(5);
		
		IndexSet cx = (IndexSet)x.clone();
		
		assertTrue(x.equals(cx));
		assertTrue(x!=cx);
		
		x.addIndex(7);
		assertTrue(!x.equals(cx));
		
	}

}
